VOL-4238: Bugfix for invalid code-generated class IDs from 11/2017 version of G.988.  Specifically EthernetFrameExtendedPm64BitClassID

Change-Id: I326273386e2f1b39a60d5f8e800dba74a652c84f
diff --git a/generated/efmbondinggroup.go b/generated/efmbondinggroup.go
index 93df527..299f00d 100644
--- a/generated/efmbondinggroup.go
+++ b/generated/efmbondinggroup.go
@@ -27,11 +27,11 @@
 
 // EfmBondingGroupClassID is the 16-bit ID for the OMCI
 // Managed entity EFM bonding group
-const EfmBondingGroupClassID ClassID = ClassID(419)
+const EfmBondingGroupClassID ClassID = ClassID(418)
 
 var efmbondinggroupBME *ManagedEntityDefinition
 
-// EfmBondingGroup (class ID #419)
+// EfmBondingGroup (class ID #418)
 //	The EFM bonding group represents a group of links that are bonded. In [IEEE 802.3], a bonding
 //	group is known as a PAF [physical medium entity (PME) aggregation function] and a link is known
 //	as a PME instance of this ME are created and deleted by the OLT.
@@ -73,7 +73,7 @@
 func init() {
 	efmbondinggroupBME = &ManagedEntityDefinition{
 		Name:    "EfmBondingGroup",
-		ClassID: 419,
+		ClassID: 418,
 		MessageTypes: mapset.NewSetWith(
 			Create,
 			Delete,
@@ -100,7 +100,7 @@
 	}
 }
 
 // NewEfmBondingGroup (class ID 419) creates the basic
 // Managed Entity definition that is used to validate an ME of this type that
 // is received from or transmitted to the OMCC.
 func NewEfmBondingGroup(params ...ParamData) (*ManagedEntity, OmciErrors) {
@@ -100,7 +100,7 @@
 }
 
-// NewEfmBondingGroup (class ID 419) creates the basic
+// NewEfmBondingGroup (class ID 418) creates the basic
 // Managed Entity definition that is used to validate an ME of this type that
 // is received from or transmitted to the OMCC.